------------------------
--  INFORMATION       --
------------------------
-- Simple Server Shutdown v1.0
-- Created by Rich Weeds Nagel (USGN: 110755) - January 8, 2013
-- http://www.unrealsoftware.de/profile.php?userid=110755
-- richnagel@centurylink.net
-- http://www.richnagel.net
--
-- This Lua script for Counter-Strike 2D allows a server administrator to
-- restart (or completely shut down) a dedicated server, along with countdown
-- notification messages (and audible sound effects) displayed to the current
-- players on the server announcing the server restart or shutdown.
--
-- Refer to the included "SimpleServerShutdown.txt" readme file for complete
-- installation and usage instructions.

------------------------
--  BEGIN FUNCTION    --
------------------------
addhook('parse','simple_server_shutdown_console_commands')
function simple_server_shutdown_console_commands(cmd)

------------------------
--  RESTART SERVER    --
------------------------
if (cmd=='simple_server_shutdown restartserver') then

	-- Notify the administrator with a message in the RCon console that a server restart has been initiated.
	print("000255000Simple Server Shutdown v1.0: Server Restart has been initiated.")

	-- Notify the players that the server will be restarted in 60 seconds.
	timer(1000,"parse",'sv_sound Env/Siren.wav')
	timer(1000,"parse",'sv_msg "255000000ATTENTION: This server will be restarted in 60 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be restarted in 30 seconds.
	timer(31000,"parse",'sv_sound Env/Siren.wav')
	timer(31000,"parse",'sv_msg "255000000ATTENTION: This server will be restarted in 30 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be restarted in 10 seconds.
	timer(51000,"parse",'sv_sound Env/Siren.wav')
	timer(51000,"parse",'sv_msg "255000000ATTENTION: This server will be restarted in 10 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be restarted in 5 seconds (with a 5 second countdown).
	timer(56000,"parse",'sv_sound Env/Click2.wav')
	timer(56000,"parse",'sv_msg "255000000Server restart in 5 seconds...@C"')
	timer(57000,"parse",'sv_sound Env/Click2.wav')
	timer(57000,"parse",'sv_msg "255000000Server restart in 4 seconds...@C"')
	timer(58000,"parse",'sv_sound Env/Click2.wav')
	timer(58000,"parse",'sv_msg "255000000Server restart in 3 seconds...@C"')
	timer(59000,"parse",'sv_sound Env/Click2.wav')
	timer(59000,"parse",'sv_msg "255000000Server restart in 2 seconds...@C"')
	timer(60000,"parse",'sv_sound Env/Click2.wav')
	timer(60000,"parse",'sv_msg "255000000Server restart in 1 second...@C"')
	timer(61000,"parse",'sv_sound Env/Alarm.wav')
	timer(61000,"parse",'sv_msg "255000000The server is now restarting, Goodbye!@C"')

	-- Kick all of the players from the server (with a kick message explaining that the server has been restarted).
	timer(63000,"simple_server_restart_kick_players")
	function simple_server_restart_kick_players()
		for id=1,32 do
			if (player(id,"exists")) then
				parse("kick "..id.." \"000255000The server has been restarted for temporary maintenance. Please rejoin the server again after a few seconds, thanks!\"")
			end
		end
	end

	-- Restart the round (effectively resetting the server).
	timer(64000,"parse",'sv_restart')

	-- Cycle to the next map in the server map rotation (just for good measure).
	timer(65000,"simple_server_restart_cycle_map")
	function simple_server_restart_cycle_map()
		parse("sv_map "..game("nextmap"))
	end

	return 1
end

------------------------
--  SHUT DOWN SERVER  --
------------------------
if (cmd=='simple_server_shutdown shutdownserver') then

	-- Notify the administrator with a message in the RCon console that a server shutdown has been initiated.
	print("000255000Simple Server Shutdown v1.0: Server Shutdown has been initiated.")

	-- Notify the players that the server will be shut down in 60 seconds.
	timer(1000,"parse",'sv_sound Env/Siren.wav')
	timer(1000,"parse",'sv_msg "255000000ATTENTION: This server will be shut down in 60 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be shut down in 30 seconds.
	timer(31000,"parse",'sv_sound Env/Siren.wav')
	timer(31000,"parse",'sv_msg "255000000ATTENTION: This server will be shut down in 30 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be shut down in 10 seconds.
	timer(51000,"parse",'sv_sound Env/Siren.wav')
	timer(51000,"parse",'sv_msg "255000000ATTENTION: This server will be shut down in 10 seconds for temporary maintenance!@C"')

	-- Notify the players that the server will be shut down in 5 seconds (with a 5 second countdown).
	timer(56000,"parse",'sv_sound Env/Click2.wav')
	timer(56000,"parse",'sv_msg "255000000Server shutdown in 5 seconds...@C"')
	timer(57000,"parse",'sv_sound Env/Click2.wav')
	timer(57000,"parse",'sv_msg "255000000Server shutdown in 4 seconds...@C"')
	timer(58000,"parse",'sv_sound Env/Click2.wav')
	timer(58000,"parse",'sv_msg "255000000Server shutdown in 3 seconds...@C"')
	timer(59000,"parse",'sv_sound Env/Click2.wav')
	timer(59000,"parse",'sv_msg "255000000Server shutdown in 2 seconds...@C"')
	timer(60000,"parse",'sv_sound Env/Click2.wav')
	timer(60000,"parse",'sv_msg "255000000Server shutdown in 1 second...@C"')
	timer(61000,"parse",'sv_sound Env/Alarm.wav')
	timer(61000,"parse",'sv_msg "255000000The server is now shutting down, Goodbye!@C"')

	-- Kick all of the players from the server (with a kick message explaining that the server has been shut down).
	timer(63000,"simple_server_shutdown_kick_players")
	function simple_server_shutdown_kick_players()
		for id=1,32 do
			if (player(id,"exists")) then
				parse("kick "..id.." \"000255000The server has been shut down for temporary maintenance. Please rejoin the server again at a later time, thanks!\"")
			end
		end
	end

	-- Shut down and terminate the server.
	timer(64000,"parse",'quit')

	return 1
end

------------------------
--  HELP SCREEN       --
------------------------
if (cmd=='simple_server_shutdown') or (cmd=='simple_server_shutdown ') or (cmd=='simple_server_shutdown ?') or (cmd=='simple_server_shutdown help') then
	print("255255255----------------------------------------")
	print("255255255Simple Server Shutdown v1.0")
	print("000255000Created by Rich Weeds Nagel (USGN: 110755) - January 8, 2013")
	print("000255000richnagel@centurylink.net")
	print("000255000http://www.richnagel.net")
	print(" ")
	print("255255255Console Commands (Dedicated Server via RCon):")
	print(" ")
	print("000255000simple_server_shutdown restartserver = Tactfully kick the players from the server, restart the round, and then cycle to the next map in the server map rotation.")
	print(" ")
	print("000255000simple_server_shutdown shutdownserver = Tactfully kick the players from the server, and then completely shut down and terminate the server.")
	print(" ")
	print("000255000simple_server_shutdown help/? = Display help screen.")
	print("000255000simple_server_shutdown version/about = Display version information.")
	print("255255255----------------------------------------")
	return 1
end

------------------------
--  VERSION SCREEN    --
------------------------
if (cmd=='simple_server_shutdown about') or (cmd=='simple_server_shutdown version') then
	print("255255255----------------------------------------")
	print("255255255Simple Server Shutdown v1.0")
	print("000255000Created by Rich Weeds Nagel (USGN: 110755) - January 8, 2013")
	print("000255000richnagel@centurylink.net")
	print("000255000http://www.richnagel.net")
	print("255255255----------------------------------------")
	return 1
end

------------------------
--  END FUNCTION      --
------------------------
end


-- EOF --